intelmq.bots.outputs.touch package — intelmq 3.1.0.alpha1 documentation

# intelmq.bots.outputs.touch package

## Submodules

## intelmq.bots.outputs.touch.output module

Using pathlib.Path.touch(path) and os.utime(path) did not work - the ctime did not change in some cases.

intelmq.bots.outputs.touch.output.BOT

  alias of `intelmq.bots.outputs.touch.output.TouchOutputBot`

class intelmq.bots.outputs.touch.output.TouchOutputBot(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.OutputBot`

  Touch a file for every event received

  path = None
  process()

## Module contents